==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/PagedDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LocalDataSourceDescriptionMetadata } from "./LocalDataSourceDescriptionMetadata";
import { PagedDataSourceDescription } from "./PagedDataSourceDescription";
/**
 * @hidden
 */
export let PagedDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class PagedDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (PagedDataSourceDescriptionMetadata.a == null) {
                PagedDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PagedDataSourceDescriptionMetadata.c(PagedDataSourceDescriptionMetadata.a);
            }
            if (a.k(PagedDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.ab(PagedDataSourceDescriptionMetadata.a);
        }
        static c(a) {
            LocalDataSourceDescriptionMetadata.c(a);
        }
        static d(a) {
            PagedDataSourceDescriptionMetadata.b(a);
            a.ad("PagedDataSource", () => new PagedDataSourceDescription());
            a.ac("PagedDataSource", PagedDataSourceDescriptionMetadata.a);
        }
    }
    PagedDataSourceDescriptionMetadata.$t = /*@__PURE__*/ markType(PagedDataSourceDescriptionMetadata, 'PagedDataSourceDescriptionMetadata');
    PagedDataSourceDescriptionMetadata.a = null;
    return PagedDataSourceDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/PagedDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LocalDataSourceDescriptionMetadata } from "./LocalDataSourceDescriptionMetadata";
import { PagedDataSourceDescription } from "./PagedDataSourceDescription";
/**
 * @hidden
 */
export let PagedDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class PagedDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (PagedDataSourceDescriptionMetadata.a == null) {
                PagedDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PagedDataSourceDescriptionMetadata.c(PagedDataSourceDescriptionMetadata.a);
            }
            if (a.k(PagedDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.ac(PagedDataSourceDescriptionMetadata.a);
        }
        static c(a) {
            LocalDataSourceDescriptionMetadata.c(a);
        }
        static d(a) {
            PagedDataSourceDescriptionMetadata.b(a);
            a.ae("PagedDataSource", () => new PagedDataSourceDescription());
            a.ad("PagedDataSource", PagedDataSourceDescriptionMetadata.a);
        }
    }
    PagedDataSourceDescriptionMetadata.$t = /*@__PURE__*/ markType(PagedDataSourceDescriptionMetadata, 'PagedDataSourceDescriptionMetadata');
    PagedDataSourceDescriptionMetadata.a = null;
    return PagedDataSourceDescriptionMetadata;
})();
